import { __awaiter } from "tslib";
import { assureDesignSystem, ResourceType, } from '@genesislcap/foundation-utils';
import { logger } from '../utils';
/**
 * @remarks
 * Attempts to use a module federation version of zero before falling back to the version that was bundled with the app.
 * @internal
 */
function zeroDesignSystemImport() {
    return __awaiter(this, void 0, void 0, function* () {
        let module;
        let type = ResourceType.remote;
        try {
            module = yield import(
            /* webpackChunkName: "foundation-zero" */
            'foundationZero/ZeroDesignSystem');
            return assureDesignSystem(module);
        }
        catch (e) {
            logger.info(`Please note remoteEntry.js load errors are expected if module federated dependencies are offline. Falling back to locally bundled versions.`);
            type = ResourceType.local;
            module = yield import(
            /* webpackChunkName: "foundation-zero" */
            '@genesislcap/foundation-zero');
            return assureDesignSystem(module);
        }
        finally {
            logger.debug(`Using '${type}' version of foundation-zero`);
        }
    });
}
/**
 * @public
 */
export const registerCommonZeroComponents = () => __awaiter(void 0, void 0, void 0, function* () {
    const { provideDesignSystem, zeroIcon, zeroButton, zeroDesignSystemProvider, zeroSelect, zeroListboxOption, zeroFlyout, zeroConnectionIndicator, } = yield zeroDesignSystemImport();
    /**
     * Register the components the app is using with the system.
     */
    provideDesignSystem().register(
    /**
     * Design system provider element used to declaratively apply zero config to every dom node in the host tree.
     */
    zeroDesignSystemProvider(), 
    /**
     * Common across most routes, so batch register these lightweight components upfront.
     */
    zeroIcon(), zeroButton(), zeroSelect(), zeroListboxOption(), zeroFlyout(), zeroConnectionIndicator);
});
